
<!--
FrozenIsBool False
-->

#Retriever

##Doc
----


> 
> Retriever instances can retrieve InsertedVariablesList given their 
> IndexInt of their corresponding table and their RowInt 
> (ie their index of their inserted line).
> 
> 

----

<small>
View the Retriever notebook on [NbViewer](http://nbviewer.ipython.org/url/shareyoursystem.ouvaton.org/Retriever.ipynb)
</small>

